#!/bin/bash
# Find executor jar and start springboot process

export JFI_HOME="/opt/jfrog"
export JFEX_APP_NAME=${JFEX_APP_NAME:-insight-executor}
export JFI_HOME_EXECUTOR="${JFI_HOME}/${JFEX_APP_NAME}"
export JFEX_LOGS=${JFEX_LOGS:-${JFI_HOME_EXECUTOR}/logs}
export JFMC_CUSTOM_ENV=${JFMC_CUSTOM_ENV:-"/opt/jfrog/jfmc/entrypoint/setenv.sh"}
export JFMC_HOSTNAME=${JFMC_HOSTNAME:-$(hostname -s)}
export JFEX_BUNDLE_LOCATION=${JFEX_BUNDLE_LOCATION:-"${JFI_HOME_EXECUTOR}/support"}
export JFEX_CONFIG=${JFEX_CONFIG:-"${JFI_HOME_EXECUTOR}/etc"}

JFEX_PORT=${JFEX_PORT:-8080}
EXECUTOR_LIB=/executor

logger() {
    DATE_TIME=$(date +"%Y-%m-%d %H:%M:%S")
    if [ -z "$CONTEXT" ]
    then
        CONTEXT=$(caller)
    fi
    MESSAGE=$1
    CONTEXT_LINE=$(echo "$CONTEXT" | awk '{print $1}')
    CONTEXT_FILE=$(echo "$CONTEXT" | awk -F"/" '{print $NF}')
    printf "%s %05s %s %s\n" "$DATE_TIME" "[$CONTEXT_LINE" "$CONTEXT_FILE]" "$MESSAGE"
    CONTEXT=
}

errorExit () {
    echo; logger "ERROR: $1"; echo
    exit 1
}

warn () {
    logger "WARNING: $1"
}

# Test directory has read/write permissions for current user
testDirectoryPermissions () {
    local dir_to_check=$1
    local error=false
    local error_type=

    [ -d ${dir_to_check} ] || errorExit "'${dir_to_check}' is not a directory"

    local id_str="'${JFMC_USER_NAME}' (id ${JFMC_USER_ID})"
    # Get current user id to check if its default jfmc uid
    local u_id=$(id -u)
    if [ "${u_id}" != ${JFMC_USER_ID} ]; then
        id_str="id ${u_id}"
    fi

    logger "Testing directory (${dir_to_check}) has read/write permissions for user ${id_str}"

    local test_file=${dir_to_check}/test-permissions

    # Write file
    if echo test > ${test_file} 1> /dev/null 2>&1; then
        # Write succeeded. Testing read...
        if cat ${test_file} > /dev/null; then
            logger "${dir_to_check} has read/write permissions for user ${id_str}"
            rm -f ${test_file}
        else
            error=true
            error_type=readable
        fi
    else
        error=true
        error_type=writable
    fi

    if [ "${error}" == true ]; then
        local stat_data=$(stat -Lc "Directory: %n, permissions: %a, owner: %U, group: %G" ${dir_to_check})
        logger "###########################################################"
        logger "${dir_to_check} is NOT ${error_type}!"
        logger "${stat_data}"
        logger "Mounted directory must be ${error_type} by user ${id_str}"
        logger "###########################################################"
        errorExit "Directory ${dir_to_check} has bad permissions for user ${id_str}"
    fi
}

# Test permissions on mounted directories
testPermissions () {
    testDirectoryPermissions ${JFEX_LOGS}
    testDirectoryPermissions ${JFEX_BUNDLE_LOCATION}
    testDirectoryPermissions ${JFEX_CONFIG}
}

# Load custom environment and set default values for required variables
# This is added to support SAAS setup
loadCustomEnv() {
    if [ -f "${JFMC_CUSTOM_ENV}" ]; then
        logger "Found a custom environment ${JFMC_CUSTOM_ENV}, loading it ..."
        source ${JFMC_CUSTOM_ENV} || errorExit "Failed to source ${JFMC_CUSTOM_ENV}"

        export JFMC_EXECUTOR_MONGO_DB=${JFMC_EXECUTOR_MONGO_DB:-"insight_executor"}
    fi
}

############### MAIN #####################

testPermissions
loadCustomEnv

EXECUTOR_JAR=${EXECUTOR_LIB}/*executor.jar
[ -f ${EXECUTOR_JAR} ] || errorExit "Could not find (or access) application jar (${EXECUTOR_JAR}) in the container"

logger "Starting application on port : ${JFEX_PORT}"

exec java -Dserver.port=${JFEX_PORT} -XX:+UseG1GC $JFMC_EXTRA_JAVA_OPTS -jar ${EXECUTOR_JAR}
